pub fn get_rb_ch_pid_a_map() -> Option<RbChPidMapping>Expand description
Create a map for rbid, ch -> paddle id. This is only for the A side and will not have an entry in case the given RB channel is connected to the B side of the paddle
pub fn get_rb_ch_pid_a_map() -> Option<RbChPidMapping>Create a map for rbid, ch -> paddle id. This is only for the A side and will not have an entry in case the given RB channel is connected to the B side of the paddle