get_vid_hid_maps

Function get_vid_hid_maps 

pub fn get_vid_hid_maps() -> Option<(HashMap<u64, u32>, HashMap<u64, u32>)>
Map the volume id as it is used in the simulation to the actual (“hardware”) detector ids

Get the map first and then query it

m = gondola.db.get_vid_hid_maps() 
print (m[0][100000000]) # tof paddle 1

Returns:

  • tuple (dict,dict) : Two maps, the first for the tof, the second for the tracker