pub struct TrackerStripGain {
pub data_id: i32,
pub strip_id: i32,
pub volume_id: i64,
pub utc_timestamp_start: i64,
pub utc_timestamp_stop: i64,
pub name: Option<String>,
pub gain: f32,
pub gain_is_mean: bool,
}Expand description
Common noise subtraction - pulse channels on the wafers and get the average adc. The gain is available as well. Data from Mengjiao’s group
Fields
data_id: i32strip_id: i32volume_id: i64utc_timestamp_start: i64utc_timestamp_stop: i64name: Option<String>gain: f32gain_is_mean: boolImplementations
Sourceimpl TrackerStripGain
impl TrackerStripGain
pub fn new() -> Self
pub fn parse_from_file<P: AsRef<Path>>(path: P) -> Result<Vec<Self>>
pub fn all_names() -> Result<Vec<String>, ConnectionError>
Sourcepub fn as_dict_by_name(
fname: &str,
) -> Result<HashMap<u32, Self>, ConnectionError>
pub fn as_dict_by_name( fname: &str, ) -> Result<HashMap<u32, Self>, ConnectionError>
Get Tracker strip cmn noise data for a certain dataset
Returns:
- HashMap<u32 [strip id], TrackerStripTransferFn>