pub fn load_calibration_db_elena(
db_path: &str,
cali_ftype: TrackerCalibrationFileType,
) -> Option<Vec<TrackerCalibrationFile>>Expand description
This loads the calbration DB for SimpleDet as provided by Elena and INFN.
This calibration db is basically a list of files and timestamps Exitence of these paths is not guaranteed.